@@ -309,6 +309,8 @@ do_main (int argc, char *argv[])
 	TrackerDomainOntology *domain_ontology;
 	gchar *dbus_name, *miner_dbus_name;
 
+	g_setenv ("GST_REGISTRY_UPDATE", "no", TRUE);
+
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
@@ -369,6 +371,9 @@ do_main (int argc, char *argv[])
 
 	tracker_content_identifier_cache_init ();
 
+	tracker_extract_module_manager_init ();
+	tracker_module_manager_load_modules ();
+
 	/* Set conditions when we use stand alone settings */
 	if (filename) {
 		return run_standalone ();
@@ -380,8 +385,6 @@ do_main (int argc, char *argv[])
 		return EXIT_FAILURE;
 	}
 
-	tracker_module_manager_load_modules ();
-
 	miner_dbus_name = tracker_domain_ontology_get_domain (domain_ontology,
 	                                                      MINER_FS_NAME_SUFFIX);
 	sparql_connection = tracker_sparql_connection_bus_new (miner_dbus_name,
