@@ -71,11 +71,11 @@ test_string_in_gslist (void)
         input = g_slist_prepend (input, g_strdup ("three"));
         input = g_slist_prepend (input, g_strdup ("four"));
 
-        g_assert (tracker_string_in_gslist ("one", input));
-        g_assert (tracker_string_in_gslist ("two", input));
-        g_assert (tracker_string_in_gslist ("three", input));
-        g_assert (tracker_string_in_gslist ("four", input));
-        g_assert (!tracker_string_in_gslist ("five", input));
+        g_assert_true (tracker_string_in_gslist ("one", input));
+        g_assert_true (tracker_string_in_gslist ("two", input));
+        g_assert_true (tracker_string_in_gslist ("three", input));
+        g_assert_true (tracker_string_in_gslist ("four", input));
+        g_assert_true (!tracker_string_in_gslist ("five", input));
 
         g_slist_foreach (input, (GFunc)g_free, NULL);
         g_slist_free (input);
@@ -102,7 +102,7 @@ test_gslist_to_string_list (void)
 	g_strfreev (result);
 
 	result = tracker_gslist_to_string_list (NULL);
-	g_assert (result != NULL);
+	g_assert_true (result != NULL);
 	g_strfreev (result);
 }
 
@@ -113,26 +113,26 @@ test_string_list_to_gslist (void)
         GSList *result = NULL;
 
         result = tracker_string_list_to_gslist ((gchar **)input, -1);
-        g_assert (result);
+        g_assert_true (result);
         g_assert_cmpint (g_slist_length (result), ==, 4);
 
         /* This function is tested in other test, so it should work or fail there also */
-        g_assert (tracker_string_in_gslist ("one", result));
-        g_assert (tracker_string_in_gslist ("two", result));
-        g_assert (tracker_string_in_gslist ("three", result));
-        g_assert (tracker_string_in_gslist ("four", result));
+        g_assert_true (tracker_string_in_gslist ("one", result));
+        g_assert_true (tracker_string_in_gslist ("two", result));
+        g_assert_true (tracker_string_in_gslist ("three", result));
+        g_assert_true (tracker_string_in_gslist ("four", result));
 
         g_slist_foreach (result, (GFunc)g_free, NULL);
         g_slist_free (result);
 
         result = tracker_string_list_to_gslist ((gchar **)input, 2);
-        g_assert (result);
+        g_assert_true (result);
         g_assert_cmpint (g_slist_length (result), ==, 2);
 
-        g_assert (tracker_string_in_gslist ("one", result));
-        g_assert (tracker_string_in_gslist ("two", result));
-        g_assert (!tracker_string_in_gslist ("three", result));
-        g_assert (!tracker_string_in_gslist ("four", result));
+        g_assert_true (tracker_string_in_gslist ("one", result));
+        g_assert_true (tracker_string_in_gslist ("two", result));
+        g_assert_true (!tracker_string_in_gslist ("three", result));
+        g_assert_true (!tracker_string_in_gslist ("four", result));
 }
 
 static void 
@@ -159,23 +159,23 @@ test_gslist_with_string_data_equal (void)
         list1 = g_slist_prepend (list1, g_strdup ("two"));
         list1 = g_slist_prepend (list1, g_strdup ("three"));
 
-        g_assert (tracker_gslist_with_string_data_equal (list1, list1));
+        g_assert_true (tracker_gslist_with_string_data_equal (list1, list1));
 
         shorty = g_slist_prepend (shorty, g_strdup ("one"));
-        g_assert (!tracker_gslist_with_string_data_equal (list1, shorty));
-        g_assert (!tracker_gslist_with_string_data_equal (shorty, list1));
+        g_assert_true (!tracker_gslist_with_string_data_equal (list1, shorty));
+        g_assert_true (!tracker_gslist_with_string_data_equal (shorty, list1));
 
         list2 = g_slist_prepend (list2, g_strdup ("one"));
         list2 = g_slist_prepend (list2, g_strdup ("two"));
         list2 = g_slist_prepend (list2, g_strdup ("three"));
-        g_assert (tracker_gslist_with_string_data_equal (list1, list2));
-        g_assert (tracker_gslist_with_string_data_equal (list2, list1));
+        g_assert_true (tracker_gslist_with_string_data_equal (list1, list2));
+        g_assert_true (tracker_gslist_with_string_data_equal (list2, list1));
 
         list3 = g_slist_prepend (list3, g_strdup ("one"));
         list3 = g_slist_prepend (list3, g_strdup ("something different"));
         list3 = g_slist_prepend (list3, g_strdup ("three"));
-        g_assert (!tracker_gslist_with_string_data_equal (list1, list3));
-        g_assert (!tracker_gslist_with_string_data_equal (list3, list1));
+        g_assert_true (!tracker_gslist_with_string_data_equal (list1, list3));
+        g_assert_true (!tracker_gslist_with_string_data_equal (list3, list1));
 
         g_slist_foreach (list1, (GFunc)g_free, NULL);
         g_slist_foreach (list2, (GFunc)g_free, NULL);
