@@ -230,10 +230,9 @@ file_notifier_finished_cb (TrackerFileNotifier *notifier,
 	}
 }
 
-static void
-test_common_context_index_dir (TestCommonContext     *fixture,
-                               const gchar           *filename,
-                               TrackerDirectoryFlags  flags)
+static GFile *
+test_common_context_get_file (TestCommonContext *fixture,
+                              const gchar       *filename)
 {
 	GFile *file;
 	gchar *path;
@@ -242,6 +241,17 @@ test_common_context_index_dir (TestCommonContext     *fixture,
 	file = g_file_new_for_path (path);
 	g_free (path);
 
+	return file;
+}
+
+static void
+test_common_context_index_dir (TestCommonContext     *fixture,
+                               const gchar           *filename,
+                               TrackerDirectoryFlags  flags)
+{
+	GFile *file;
+
+	file = test_common_context_get_file (fixture, filename);
 	tracker_indexing_tree_add (fixture->indexing_tree, file, flags);
 	g_object_unref (file);
 }
@@ -251,16 +261,32 @@ test_common_context_remove_dir (TestCommonContext     *fixture,
 				const gchar           *filename)
 {
 	GFile *file;
-	gchar *path;
-
-	path = g_build_filename (fixture->test_path, filename, NULL);
-	file = g_file_new_for_path (path);
-	g_free (path);
 
+	file = test_common_context_get_file (fixture, filename);
 	tracker_indexing_tree_remove (fixture->indexing_tree, file);
 	g_object_unref (file);
 }
 
+static void
+assert_notifier_properties (TrackerFileNotifier     *notifier,
+			    TrackerSparqlConnection *connection,
+			    TrackerIndexingTree     *tree,
+			    const gchar             *attributes)
+{
+	g_autoptr (GObject) c = NULL, i = NULL;
+	g_autofree gchar *a = NULL;
+
+	g_object_get (notifier,
+		      "connection", &c,
+		      "indexing-tree", &i,
+		      "file-attributes", &a,
+		      NULL);
+
+	g_assert_true (connection == TRACKER_SPARQL_CONNECTION (c));
+	g_assert_true (tree == TRACKER_INDEXING_TREE (i));
+	g_assert_cmpstr (attributes, ==, a);
+}
+
 static void
 test_common_context_setup (TestCommonContext *fixture,
                            gconstpointer      data)
@@ -290,9 +316,18 @@ test_common_context_setup (TestCommonContext *fixture,
 	tracker_indexing_tree_set_filter_hidden (fixture->indexing_tree, TRUE);
 
 	fixture->main_loop = g_main_loop_new (NULL, FALSE);
-	fixture->notifier = tracker_file_notifier_new (fixture->indexing_tree, FALSE,
+	fixture->notifier = tracker_file_notifier_new (fixture->indexing_tree,
 	                                               fixture->connection,
-	                                               G_FILE_ATTRIBUTE_STANDARD_TYPE);
+	                                               G_FILE_ATTRIBUTE_STANDARD_TYPE ","
+	                                               G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN ","
+	                                               G_FILE_ATTRIBUTE_TIME_MODIFIED);
+
+	assert_notifier_properties (fixture->notifier,
+	                            fixture->connection,
+	                            fixture->indexing_tree,
+	                            G_FILE_ATTRIBUTE_STANDARD_TYPE ","
+	                            G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN ","
+	                            G_FILE_ATTRIBUTE_TIME_MODIFIED);
 
 	g_signal_connect (fixture->notifier, "file-created",
 	                  G_CALLBACK (file_notifier_file_created_cb), fixture);
@@ -591,6 +626,82 @@ test_file_notifier_crawling_ignore_within_recursive (TestCommonContext *fixture,
 	tracker_file_notifier_stop (fixture->notifier);
 }
 
+static void
+test_file_notifier_crawling_root_removal1 (TestCommonContext *fixture,
+                                           gconstpointer      data)
+{
+	FilesystemOperation expected_results[] = {
+		{ OPERATION_CREATE, "non-recursive", NULL },
+		{ OPERATION_CREATE, "non-recursive/ccc", NULL },
+		{ OPERATION_CREATE, "non-recursive/folder", NULL },
+		{ OPERATION_DELETE, "recursive", NULL },
+	};
+
+	CREATE_FOLDER (fixture, "recursive/folder");
+	CREATE_UPDATE_FILE (fixture, "recursive/folder/aaa");
+	CREATE_UPDATE_FILE (fixture, "recursive/bbb");
+	CREATE_UPDATE_FILE (fixture, "non-recursive/ccc");
+	CREATE_FOLDER (fixture, "non-recursive/folder");
+	CREATE_UPDATE_FILE (fixture, "non-recursive/folder/ddd");
+
+	/* Add 2 index roots, then remove the first one */
+	test_common_context_index_dir (fixture, "recursive",
+	                               TRACKER_DIRECTORY_FLAG_RECURSE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
+	test_common_context_index_dir (fixture, "non-recursive",
+	                               TRACKER_DIRECTORY_FLAG_NONE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
+
+	tracker_file_notifier_start (fixture->notifier);
+
+	/* Remove after start */
+	test_common_context_remove_dir (fixture, "recursive");
+
+	test_common_context_expect_results (fixture, expected_results,
+					    G_N_ELEMENTS (expected_results),
+					    2, TRUE);
+
+	tracker_file_notifier_stop (fixture->notifier);
+}
+
+static void
+test_file_notifier_crawling_root_removal2 (TestCommonContext *fixture,
+                                           gconstpointer      data)
+{
+	FilesystemOperation expected_results[] = {
+		{ OPERATION_CREATE, "non-recursive", NULL },
+		{ OPERATION_CREATE, "non-recursive/ccc", NULL },
+		{ OPERATION_CREATE, "non-recursive/folder", NULL },
+		{ OPERATION_DELETE, "recursive", NULL },
+	};
+
+	CREATE_FOLDER (fixture, "recursive/folder");
+	CREATE_UPDATE_FILE (fixture, "recursive/folder/aaa");
+	CREATE_UPDATE_FILE (fixture, "recursive/bbb");
+	CREATE_UPDATE_FILE (fixture, "non-recursive/ccc");
+	CREATE_FOLDER (fixture, "non-recursive/folder");
+	CREATE_UPDATE_FILE (fixture, "non-recursive/folder/ddd");
+
+	/* Add 2 index roots, then remove the first one */
+	test_common_context_index_dir (fixture, "recursive",
+	                               TRACKER_DIRECTORY_FLAG_RECURSE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
+	test_common_context_index_dir (fixture, "non-recursive",
+	                               TRACKER_DIRECTORY_FLAG_NONE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
+
+	/* Remove before start */
+	test_common_context_remove_dir (fixture, "recursive");
+
+	tracker_file_notifier_start (fixture->notifier);
+
+	test_common_context_expect_results (fixture, expected_results,
+					    G_N_ELEMENTS (expected_results),
+					    2, TRUE);
+
+	tracker_file_notifier_stop (fixture->notifier);
+}
+
 static void
 test_file_notifier_changes_remove_non_recursive (TestCommonContext *fixture,
 						 gconstpointer      data)
@@ -663,6 +774,134 @@ test_file_notifier_changes_remove_ignore (TestCommonContext *fixture,
 	tracker_file_notifier_stop (fixture->notifier);
 }
 
+static void
+test_file_notifier_changes_ignore_non_recursive (TestCommonContext *fixture,
+                                                 gconstpointer      data)
+{
+	FilesystemOperation expected_results[] = {
+		{ OPERATION_DELETE, "non-recursive/folder", NULL },
+	};
+	FilesystemOperation expected_results2[] = {
+		{ OPERATION_CREATE, "non-recursive/folder", NULL }
+	};
+
+	/* Start off from non-recursive crawl test case */
+	test_file_notifier_crawling_non_recursive (fixture, data);
+
+	/* Add ignored index root on the file */
+	test_common_context_index_dir (fixture, "non-recursive/folder",
+	                               TRACKER_DIRECTORY_FLAG_IGNORE);
+	tracker_file_notifier_start (fixture->notifier);
+	test_common_context_expect_results (fixture, expected_results,
+	                                    G_N_ELEMENTS (expected_results),
+	                                    1, FALSE);
+	tracker_file_notifier_stop (fixture->notifier);
+
+	/* And remove it */
+	test_common_context_remove_dir (fixture, "non-recursive/folder");
+	tracker_file_notifier_start (fixture->notifier);
+	test_common_context_expect_results (fixture, expected_results2,
+	                                    G_N_ELEMENTS (expected_results2),
+	                                    1, FALSE);
+	tracker_file_notifier_stop (fixture->notifier);
+}
+
+static void
+test_file_notifier_changes_update_child (TestCommonContext *fixture,
+                                         gconstpointer      data)
+{
+	FilesystemOperation expected_results[] = {
+		{ OPERATION_CREATE, "recursive", NULL },
+		{ OPERATION_CREATE, "recursive/folder", NULL },
+		{ OPERATION_CREATE, "recursive/folder/aaa", NULL },
+		{ OPERATION_CREATE, "recursive/bbb", NULL },
+	};
+	FilesystemOperation expected_results2[] = {
+		{ OPERATION_CREATE, "recursive/folder", NULL },
+		{ OPERATION_CREATE, "recursive/folder/aaa", NULL },
+	};
+	FilesystemOperation expected_results3[] = {
+		{ OPERATION_UPDATE, "recursive/folder/aaa", NULL },
+	};
+	GFile *file;
+
+	CREATE_FOLDER (fixture, "recursive/folder");
+	CREATE_UPDATE_FILE (fixture, "recursive/folder/aaa");
+	CREATE_UPDATE_FILE (fixture, "recursive/bbb");
+
+	test_common_context_index_dir (fixture, "recursive",
+	                               TRACKER_DIRECTORY_FLAG_RECURSE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
+
+	tracker_file_notifier_start (fixture->notifier);
+
+	test_common_context_expect_results (fixture, expected_results,
+	                                    G_N_ELEMENTS (expected_results),
+	                                    2, TRUE);
+
+	tracker_file_notifier_stop (fixture->notifier);
+
+	/* Update folder */
+	file = test_common_context_get_file (fixture, "recursive/folder");
+	tracker_indexing_tree_notify_update (fixture->indexing_tree,
+	                                     file, TRUE);
+	g_object_unref (file);
+
+	tracker_file_notifier_start (fixture->notifier);
+	test_common_context_expect_results (fixture, expected_results2,
+	                                    G_N_ELEMENTS (expected_results2),
+	                                    2, TRUE);
+	tracker_file_notifier_stop (fixture->notifier);
+
+	/* Update file */
+	file = test_common_context_get_file (fixture, "recursive/folder/aaa");
+	tracker_indexing_tree_notify_update (fixture->indexing_tree,
+	                                     file, FALSE);
+	g_object_unref (file);
+
+	tracker_file_notifier_start (fixture->notifier);
+	test_common_context_expect_results (fixture, expected_results3,
+	                                    G_N_ELEMENTS (expected_results3),
+	                                    2, TRUE);
+	tracker_file_notifier_stop (fixture->notifier);
+}
+
+static void
+test_file_notifier_start_stop (TestCommonContext *fixture,
+                               gconstpointer      data)
+{
+	FilesystemOperation expected_results[] = {
+	};
+	FilesystemOperation expected_results2[] = {
+		{ OPERATION_CREATE, "non-recursive", NULL },
+		{ OPERATION_CREATE, "non-recursive/ccc", NULL },
+		{ OPERATION_CREATE, "non-recursive/folder", NULL },
+	};
+
+	CREATE_UPDATE_FILE (fixture, "non-recursive/ccc");
+	CREATE_FOLDER (fixture, "non-recursive/folder");
+	CREATE_UPDATE_FILE (fixture, "non-recursive/folder/ddd");
+
+	test_common_context_index_dir (fixture, "non-recursive",
+	                               TRACKER_DIRECTORY_FLAG_NONE |
+	                               TRACKER_DIRECTORY_FLAG_CHECK_MTIME);
+
+	/* Start and stop immediately */
+	tracker_file_notifier_start (fixture->notifier);
+	tracker_file_notifier_stop (fixture->notifier);
+
+	test_common_context_expect_results (fixture, expected_results,
+					    G_N_ELEMENTS (expected_results),
+					    1, TRUE);
+
+	/* Start and process changes */
+	tracker_file_notifier_start (fixture->notifier);
+	test_common_context_expect_results (fixture, expected_results2,
+					    G_N_ELEMENTS (expected_results2),
+					    1, TRUE);
+	tracker_file_notifier_stop (fixture->notifier);
+}
+
 static void
 test_file_notifier_monitor_updates_non_recursive (TestCommonContext *fixture,
                                                   gconstpointer      data)
@@ -781,6 +1020,10 @@ main (gint    argc,
 	          test_file_notifier_crawling_recursive_within_non_recursive);
 	test_add ("/libtracker-miner/file-notifier/crawling-ignore-within-recursive",
 	          test_file_notifier_crawling_ignore_within_recursive);
+	test_add ("/libtracker-miner/file-notifier/crawling-root-removal1",
+	          test_file_notifier_crawling_root_removal1);
+	test_add ("/libtracker-miner/file-notifier/crawling-root-removal2",
+	          test_file_notifier_crawling_root_removal2);
 
 	/* Config changes */
 	test_add ("/libtracker-miner/file-notifier/changes-remove-non-recursive",
@@ -789,6 +1032,12 @@ main (gint    argc,
 		  test_file_notifier_changes_remove_recursive);
 	test_add ("/libtracker-miner/file-notifier/changes-remove-ignore",
 		  test_file_notifier_changes_remove_ignore);
+	test_add ("/libtracker-miner/file-notifier/changes-ignore-non-recursive",
+		  test_file_notifier_changes_ignore_non_recursive);
+	test_add ("/libtracker-miner/file-notifier/changes-update-child",
+		  test_file_notifier_changes_update_child);
+	test_add ("/libtracker-miner/file-notifier/start-stop",
+		  test_file_notifier_start_stop);
 
 	/* Monitoring */
 	test_add ("/libtracker-miner/file-notifier/monitor-updates-non-recursive",
