@@ -169,14 +169,17 @@ test_miner_init (TestMiner *miner)
 }
 
 static TrackerMinerFS *
-test_miner_new (TrackerSparqlConnection  *conn,
-                GError                  **error)
+test_miner_new (TrackerSparqlConnection *conn)
 {
-	return g_initable_new (test_miner_get_type (),
-	                       NULL, error,
-	                       "connection", conn,
-	                       "file-attributes", "standard::*,time::*",
-	                       NULL);
+	g_autoptr (TrackerIndexingTree) indexing_tree = NULL;
+
+	indexing_tree = tracker_indexing_tree_new ();
+
+	return g_object_new (test_miner_get_type (),
+	                     "indexing-tree", indexing_tree,
+			     "connection", conn,
+			     "file-attributes", "standard::*,time::*",
+			     NULL);
 }
 
 static gboolean
@@ -257,10 +260,10 @@ fixture_setup (TrackerMinerFSTestFixture *fixture,
 					  "CREATE SILENT GRAPH tracker:Pictures; "
 					  "CREATE SILENT GRAPH tracker:Audio; "
 					  "CREATE SILENT GRAPH tracker:Video ",
-					  NULL, NULL);
-
-	fixture->miner = test_miner_new (fixture->connection, &error);
+					  NULL, &error);
 	g_assert_no_error (error);
+
+	fixture->miner = test_miner_new (fixture->connection);
 }
 
 static void
